Глава 5. Использование
Пред. |  | След.

## Глава 5. Использование

## Добавление музыки

Для добавления музыки в медиатеку её следует сложить в папку `/var/lib/ardj/incoming` и выполнить команду ardj add-incoming-tracks, или послать jabber-боту команду upload. После этого музыка будет обработана (посчитан ReplayGain) и перемещена в медиатеку. Добавлять файлы в медиатеку вручную не следует: в базу данных они не попадут; вручную их там можно только спрятать.

При копировании в медиатеку из метаданных файлов считываются значения тэгов "artist" и "title", остальные привычные тэги игнорируются. Из непривычных поддерживается тэг "ardj", который может содержать метки, пример значения:

    ardj=1;labels=music,rock,loud

Пред. |  | След.
Подмотка | Начало | Оценка композиций